@@ -41,6 +41,7 @@
 #include <QElapsedTimer>
 #include <QHash>
 #include <QMap>
+#include <QMutex>
 #include <QPointer>
 #include <QSet>
 #include <QVector>
@@ -541,7 +542,6 @@ namespace BitTorrent
         void populateAdditionalTrackers();
         void enableIPFilter();
         void disableIPFilter();
-        void processTrackerStatuses();
         void processTorrentShareLimits(TorrentImpl *torrent);
         void populateExcludedFileNamesRegExpList();
         void prepareStartup();
@@ -605,7 +605,7 @@ namespace BitTorrent
         void saveStatistics() const;
         void loadStatistics();
 
-        void updateTrackerEntryStatuses(lt::torrent_handle torrentHandle, QHash<std::string, QHash<lt::tcp::endpoint, QMap<int, int>>> updatedTrackers);
+        void updateTrackerEntryStatuses(lt::torrent_handle torrentHandle);
 
         void handleRemovedTorrent(const TorrentID &torrentID, const QString &partfileRemoveError = {});
 
@@ -794,6 +794,7 @@ namespace BitTorrent
         // This field holds amounts of peers reported by trackers in their responses to announces
         // (torrent.tracker_name.tracker_local_endpoint.protocol_version.num_peers)
         QHash<lt::torrent_handle, QHash<std::string, QHash<lt::tcp::endpoint, QMap<int, int>>>> m_updatedTrackerStatuses;
+        QMutex m_updatedTrackerStatusesMutex;
 
         // I/O errored torrents
         QSet<TorrentID> m_recentErroredTorrents;
